@@ -82,7 +82,6 @@ func TestNew(t *testing.T) {
 					Release:   "release-info",
 					SourceRpm: "sqlite-3.26.0-6.el8.src.rpm",
 					Size:      40,
-					License:   "license-info",
 					Vendor:    "vendor-info",
 					Files: []syftPkg.RpmdbFileRecord{
 						{
@@ -185,7 +184,6 @@ func TestNew(t *testing.T) {
 					OriginPackage: "libcurl",
 					Maintainer:    "somone",
 					Version:       "1.2.3",
-					License:       "Apache",
 					Architecture:  "a",
 					URL:           "a",
 					Description:   "a",
@@ -219,7 +217,6 @@ func TestNew(t *testing.T) {
 				Metadata: syftPkg.PythonPackageMetadata{
 					Name:                 "a",
 					Version:              "a",
-					License:              "a",
 					Author:               "a",
 					AuthorEmail:          "a",
 					Platform:             "a",
@@ -418,6 +415,19 @@ func TestNew(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "python-requirements-metadata",
+			syftPkg: syftPkg.Package{
+				MetadataType: syftPkg.PythonRequirementsMetadataType,
+				Metadata: syftPkg.PythonRequirementsMetadata{
+					Name:              "a",
+					Extras:            []string{"a"},
+					VersionConstraint: "a",
+					URL:               "a",
+					Markers:           map[string]string{"a": "a"},
+				},
+			},
+		},
 		{
 			name: "binary-metadata",
 			syftPkg: syftPkg.Package{
@@ -486,6 +496,25 @@ func TestNew(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "r-description-file-metadata",
+			syftPkg: syftPkg.Package{
+				MetadataType: syftPkg.RDescriptionFileMetadataType,
+				Metadata: syftPkg.RDescriptionFileMetadata{
+					Title:            "a",
+					Description:      "a",
+					Author:           "a",
+					Maintainer:       "a",
+					URL:              []string{"a"},
+					Repository:       "a",
+					Built:            "a",
+					NeedsCompilation: true,
+					Imports:          []string{"a"},
+					Depends:          []string{"a"},
+					Suggests:         []string{"a"},
+				},
+			},
+		},
 	}
 
 	// capture each observed metadata type, we should see all of them relate to what syft provides by the end of testing
@@ -515,8 +544,8 @@ func TestNew(t *testing.T) {
 	}
 }
 
-func TestFromCatalog_DoesNotPanic(t *testing.T) {
-	catalog := syftPkg.NewCatalog()
+func TestFromCollection_DoesNotPanic(t *testing.T) {
+	collection := syftPkg.NewCollection()
 
 	examplePackage := syftPkg.Package{
 		Name:    "test",
@@ -527,19 +556,19 @@ func TestFromCatalog_DoesNotPanic(t *testing.T) {
 		Type: syftPkg.NpmPkg,
 	}
 
-	catalog.Add(examplePackage)
+	collection.Add(examplePackage)
 	// add it again!
-	catalog.Add(examplePackage)
+	collection.Add(examplePackage)
 
 	assert.NotPanics(t, func() {
-		_ = FromCatalog(catalog, SynthesisConfig{})
+		_ = FromCollection(collection, SynthesisConfig{})
 	})
 }
 
-func TestFromCatalog_GeneratesCPEs(t *testing.T) {
-	catalog := syftPkg.NewCatalog()
+func TestFromCollection_GeneratesCPEs(t *testing.T) {
+	collection := syftPkg.NewCollection()
 
-	catalog.Add(syftPkg.Package{
+	collection.Add(syftPkg.Package{
 		Name:    "first",
 		Version: "1",
 		CPEs: []cpe.CPE{
@@ -547,18 +576,18 @@ func TestFromCatalog_GeneratesCPEs(t *testing.T) {
 		},
 	})
 
-	catalog.Add(syftPkg.Package{
+	collection.Add(syftPkg.Package{
 		Name:    "second",
 		Version: "2",
 	})
 
 	// doesn't generate cpes when no flag
-	pkgs := FromCatalog(catalog, SynthesisConfig{})
+	pkgs := FromCollection(collection, SynthesisConfig{})
 	assert.Len(t, pkgs[0].CPEs, 1)
 	assert.Len(t, pkgs[1].CPEs, 0)
 
 	// does generate cpes with the flag
-	pkgs = FromCatalog(catalog, SynthesisConfig{
+	pkgs = FromCollection(collection, SynthesisConfig{
 		GenerateMissingCPEs: true,
 	})
 	assert.Len(t, pkgs[0].CPEs, 1)
@@ -641,8 +670,8 @@ func Test_RemoveBinaryPackagesByOverlap(t *testing.T) {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			catalog := removePackagesByOverlap(test.sbom.catalog, test.sbom.relationships)
-			pkgs := FromCatalog(catalog, SynthesisConfig{})
+			catalog := removePackagesByOverlap(test.sbom.collection, test.sbom.relationships)
+			pkgs := FromCollection(catalog, SynthesisConfig{})
 			var pkgNames []string
 			for _, p := range pkgs {
 				pkgNames = append(pkgNames, fmt.Sprintf("%s:%s@%s", p.Type, p.Name, p.Version))
@@ -653,7 +682,7 @@ func Test_RemoveBinaryPackagesByOverlap(t *testing.T) {
 }
 
 type catalogRelationships struct {
-	catalog       *syftPkg.Catalog
+	collection    *syftPkg.Collection
 	relationships []artifact.Relationship
 }
 
@@ -704,10 +733,10 @@ func catalogWithOverlaps(packages []string, overlaps []string) catalogRelationsh
 		})
 	}
 
-	catalog := syftPkg.NewCatalog(pkgs...)
+	catalog := syftPkg.NewCollection(pkgs...)
 
 	return catalogRelationships{
-		catalog:       catalog,
+		collection:    catalog,
 		relationships: relationships,
 	}
 }
