@@ -2,6 +2,7 @@ package models
 
 import (
 	"testing"
+	"time"
 
 	"github.com/stretchr/testify/assert"
 
@@ -93,3 +94,26 @@ func TestPackagesAreSorted(t *testing.T) {
 
 	assert.Equal(t, []string{"CVE-1999-0001", "CVE-1999-0002", "CVE-1999-0003"}, actualVulnerabilities)
 }
+
+func TestTimestampValidFormat(t *testing.T) {
+
+	matches := match.NewMatches()
+
+	ctx := pkg.Context{
+		Source: nil,
+		Distro: nil,
+	}
+
+	doc, err := NewDocument(nil, ctx, matches, nil, nil, nil, nil)
+	if err != nil {
+		t.Fatalf("unable to get document: %+v", err)
+	}
+
+	assert.NotEmpty(t, doc.Descriptor.Timestamp)
+	// Check format is RFC3339 compatible e.g. 2023-04-21T00:22:06.491137+01:00
+	_, timeErr := time.Parse(time.RFC3339, doc.Descriptor.Timestamp)
+	if timeErr != nil {
+		t.Fatalf("unable to parse time: %+v", timeErr)
+	}
+
+}
